searchData={"content_type":"text/markdown","items":[{"doc":"Module responsible for interacting with a WebRTC peer.\n\nNew tracks are specified by SDP negotiation conducted by messages\n`t:signal_message/0`, and then linking corresponding\n`:input` and `:output` pads with ids reported via `t:new_track_notification/0`\n\nThe tracks can be manipulated by sending `t:track_message/0`.\n\nTo initiate or modify the connection, the bin sends and expects to receive\n`t:signal_message/0`.","ref":"Membrane.WebRTC.EndpointBin.html","title":"Membrane.WebRTC.EndpointBin","type":"module"},{"doc":"Passed via struct `t:Membrane.WebRTC.EndpointBin.t/0`\n\n- `direction`  \n\n  ```\n  direction()\n  ```\n  \n  Default value: `:sendrecv`  \n  Direction of EndpointBin. Determines whether\n  EndpointBin can send, receive or both send and receive media.\n  For more information refer to t:direction/0.\n\n\n- `handshake_opts`  \n\n  ```\n  Keyword.t()\n  ```\n  \n  Default value: `[]`  \n  Keyword list with options for handshake module. For more information please\n  refer to `t:ExDTLS.opts_t/0`\n\n\n\n- `rtcp_receiver_report_interval`  \n\n  ```\n  Membrane.Time.t() | nil\n  ```\n  \n  Default value: `nil`  \n  Receiver reports's generation interval, set to nil to avoid reports generation\n\n\n\n- `rtcp_sender_report_interval`  \n\n  ```\n  Membrane.Time.t() | nil\n  ```\n  \n  Default value: `nil`  \n  Sender reports's generation interval, set to nil to avoid reports generation\n\n\n\n- `filter_codecs`  \n\n  ```\n  (Membrane.WebRTC.Track.Encoding.t() -> boolean())\n  ```\n  \n  Default value: `&Membrane.WebRTC.SDP.filter_encodings/1`  \n  Defines function which will filter SDP m-line by codecs\n\n\n\n- `extensions`  \n\n  ```\n  [Extension.t()]\n  ```\n  \n  Default value: `[]`  \n  List of WebRTC extensions that should be enabled\n\n\n\n- `log_metadata`  \n\n  ```\n  :list\n  ```\n  \n  Default value: `[]`  \n  Logger metadata used for endpoint bin and all its descendants\n\n\n\n- `integrated_turn_options`  \n\n  ```\n  [ICE.Endpoint.integrated_turn_options_t()]\n  ```\n  \n  Default value: `[]`  \n  Integrated TURN Options\n\n\n\n- `simulcast?`  \n\n  ```\n  boolean()\n  ```\n  \n  Default value: `true`  \n  Whether to accept simulcast tracks or not.\n  If set to `false`, simulcast tracks will be disabled i.e.\n  sender will not send them.\n\n\n\n- `trace_metadata`  \n\n  ```\n  :list\n  ```\n  \n  Default value: `[]`  \n  A list of tuples to merge into Otel spans\n\n\n\n- `trace_context`  \n\n  ```\n  :list | any()\n  ```\n  \n  Default value: `[]`  \n  Trace context for otel propagation\n\n\n\n- `parent_span`  \n\n  ```\n  :opentelemetry.span_ctx() | nil\n  ```\n  \n  Default value: `nil`  \n  Parent span of endpoint_bin.life_span\n\n\n\n- `telemetry_label`  \n\n  ```\n  Membrane.TelemetryMetrics.label()\n  ```\n  \n  Default value: `[]`  \n  Label passed to Membrane.TelemetryMetrics functions","ref":"Membrane.WebRTC.EndpointBin.html#module-bin-options","title":"Bin options - Membrane.WebRTC.EndpointBin","type":"module"},{"doc":"### `:input`\n\nAccepted formats:\n```\n_any\n```\n\nDirection: | `:input`\nAvailability: | `:on_request`\nPad options:\n\n- `use_payloader?`  \n\n  ```\n  boolean()\n  ```\n  \n  Default value: `true`  \n  Defines if incoming stream should be payloaded based on given encoding.\n  Otherwise the stream is assumed  be in RTP format.\n\n\n\n### `:output`\n\nAccepted formats:\n```\n_any\n```\n\nDirection: | `:output`\nAvailability: | `:on_request`\nPad options:\n\n- `extensions`  \n\n  ```\n  [Membrane.RTP.SessionBin.extension_t()]\n  ```\n  \n  Default value: `[]`  \n  List of general extensions that will be applied to the SessionBin's output pad\n\n\n- `use_depayloader?`  \n\n  ```\n  boolean()\n  ```\n  \n  Default value: `true`  \n  Defines if the outgoing stream should get depayloaded.\n  \n  This option should be used as a convenience, it is not necessary as the new track notification\n  returns a depayloading filter's definition that can be attached to the output pad\n  to work the same way as with the option set to true.","ref":"Membrane.WebRTC.EndpointBin.html#module-pads","title":"Pads - Membrane.WebRTC.EndpointBin","type":"module"},{"doc":"Returns description of options available for this module","ref":"Membrane.WebRTC.EndpointBin.html#options/0","title":"Membrane.WebRTC.EndpointBin.options/0","type":"function"},{"doc":"Message that adds or removes tracks.","ref":"Membrane.WebRTC.EndpointBin.html#t:alter_tracks_message/0","title":"Membrane.WebRTC.EndpointBin.alter_tracks_message/0","type":"type"},{"doc":"Type describing possible media flow directions.\n\n* `:recvonly` - only receive media from the peer\n* `:sendonly` - only send media to the peer\n* `:sendrecv` - both send and receive media from the peer","ref":"Membrane.WebRTC.EndpointBin.html#t:direction/0","title":"Membrane.WebRTC.EndpointBin.direction/0","type":"type"},{"doc":"Options for pad `:input`","ref":"Membrane.WebRTC.EndpointBin.html#t:input_pad_opts/0","title":"Membrane.WebRTC.EndpointBin.input_pad_opts/0","type":"type"},{"doc":"","ref":"Membrane.WebRTC.EndpointBin.html#t:new_track_notification/0","title":"Membrane.WebRTC.EndpointBin.new_track_notification/0","type":"type"},{"doc":"Options for pad `:output`","ref":"Membrane.WebRTC.EndpointBin.html#t:output_pad_opts/0","title":"Membrane.WebRTC.EndpointBin.output_pad_opts/0","type":"type"},{"doc":"","ref":"Membrane.WebRTC.EndpointBin.html#t:signal_message/0","title":"Membrane.WebRTC.EndpointBin.signal_message/0","type":"type"},{"doc":"Struct containing options for `Membrane.WebRTC.EndpointBin`","ref":"Membrane.WebRTC.EndpointBin.html#t:t/0","title":"Membrane.WebRTC.EndpointBin.t/0","type":"type"},{"doc":"","ref":"Membrane.WebRTC.EndpointBin.html#t:track_message/0","title":"Membrane.WebRTC.EndpointBin.track_message/0","type":"type"},{"doc":"A module that provides mappings between `ExSDP.Attribute.Extmap` and modules implementing\n`Membrane.WebRTC.Extension` behaviour.","ref":"Membrane.WebRTC.Extension.html","title":"Membrane.WebRTC.Extension","type":"behaviour"},{"doc":"Adds information about extension to an SDP media.","ref":"Membrane.WebRTC.Extension.html#c:add_to_media/4","title":"Membrane.WebRTC.Extension.add_to_media/4","type":"callback"},{"doc":"Given an SDP media, a list of supported extensions and supported `Extmap`s, adds corresponding\nextensions to the media.","ref":"Membrane.WebRTC.Extension.html#add_to_media/5","title":"Membrane.WebRTC.Extension.add_to_media/5","type":"function"},{"doc":"Given a list of supported extensions, maps a supported `Extmap` to an `RTP.SessionBin.rtp_extension_t()`.\n\n`:inbound`/`:outbound` denotes track type `extmap` was specified for.","ref":"Membrane.WebRTC.Extension.html#as_rtp_extension/3","title":"Membrane.WebRTC.Extension.as_rtp_extension/3","type":"function"},{"doc":"Given a list of supported extensions and a supported `Extmap`, generates a mapping from a name provided\nby an extension to an ID provided by the `Extmap`.","ref":"Membrane.WebRTC.Extension.html#as_rtp_mapping/2","title":"Membrane.WebRTC.Extension.as_rtp_mapping/2","type":"function"},{"doc":"Returns a boolean indicating whether an extension is compatible with given encoding.","ref":"Membrane.WebRTC.Extension.html#c:compatible?/1","title":"Membrane.WebRTC.Extension.compatible?/1","type":"callback"},{"doc":"Given a list of supported extensions, returns an extension that corresponds to given `Extmap`\nor `:not_supported` if there is no such extension.","ref":"Membrane.WebRTC.Extension.html#from_extmap/2","title":"Membrane.WebRTC.Extension.from_extmap/2","type":"function"},{"doc":"Returns a module that implements the extension in `Membrane.RTP.SessionBin` or `:no_rtp_module` if such\nsuch module would only forward buffers to next element.\n\n`:inbound`/`:outbound` denotes track type this extension was specified for.","ref":"Membrane.WebRTC.Extension.html#c:get_rtp_module/3","title":"Membrane.WebRTC.Extension.get_rtp_module/3","type":"callback"},{"doc":"Creates a `Membrane.WebRTC.Extension` struct for a specific extension.","ref":"Membrane.WebRTC.Extension.html#c:new/1","title":"Membrane.WebRTC.Extension.new/1","type":"callback"},{"doc":"Given a list of supported extensions, checks if there is an extension that corresponds to\ngiven `Extmap` and encoding.","ref":"Membrane.WebRTC.Extension.html#supported?/3","title":"Membrane.WebRTC.Extension.supported?/3","type":"function"},{"doc":"Returns an URI that identifies extension in SDP","ref":"Membrane.WebRTC.Extension.html#c:uri/0","title":"Membrane.WebRTC.Extension.uri/0","type":"callback"},{"doc":"","ref":"Membrane.WebRTC.Extension.html#t:maybe_t/0","title":"Membrane.WebRTC.Extension.maybe_t/0","type":"type"},{"doc":"* module - extension specific module which implement `Membrane.WebRTC.Extension` behaviour\n  * rtp_opts - options for RTP module. This allows configuring RTP module to your needs\n  * uri - a URI that identifies extension in SDP\n  * name - an atom identifying the extension in `Membrane.RTP.SessionBin`","ref":"Membrane.WebRTC.Extension.html#t:t/0","title":"Membrane.WebRTC.Extension.t/0","type":"type"},{"doc":"Module implementing `Membrane.WebRTC.Extension` behaviour for Media Identification RTP Header extension.\n\nThis extension is described at https://tools.ietf.org/pdf/draft-ietf-mmusic-rfc8843bis-09.pdf.","ref":"Membrane.WebRTC.Extension.Mid.html","title":"Membrane.WebRTC.Extension.Mid","type":"module"},{"doc":"Module implementing `Membrane.WebRTC.Extension` behaviour for Repaired RTP Stream Identifier RTP Header extension.\n\nThis extension is described in RFC 8852.","ref":"Membrane.WebRTC.Extension.RepairedRid.html","title":"Membrane.WebRTC.Extension.RepairedRid","type":"module"},{"doc":"Module implementing `Membrane.WebRTC.Extension` behaviour for RTP Stream Identifier RTP Header extension.\n\nThis extension is described in RFC 8852.","ref":"Membrane.WebRTC.Extension.Rid.html","title":"Membrane.WebRTC.Extension.Rid","type":"module"},{"doc":"Module implementing `Membrane.WebRTC.Extension` behaviour for Transport-wide Congestion Control RTP Header extension.\n\nThis extension is described at https://datatracker.ietf.org/doc/html/draft-holmer-rmcat-transport-wide-cc-extensions-01.","ref":"Membrane.WebRTC.Extension.TWCC.html","title":"Membrane.WebRTC.Extension.TWCC","type":"module"},{"doc":"Module implementing `Membrane.WebRTC.Extension` behaviour for Client-to-Mixer Audio Level Indication RTP Header extension.\n\nThis extension is described in RFC 6464.","ref":"Membrane.WebRTC.Extension.VAD.html","title":"Membrane.WebRTC.Extension.VAD","type":"module"},{"doc":"Defines a list of metrics that can be aggregated based on events from `membrane_webrtc_plugin`.","ref":"Membrane.WebRTC.Metrics.html","title":"Membrane.WebRTC.Metrics","type":"module"},{"doc":"","ref":"Membrane.WebRTC.Metrics.html#metrics/0","title":"Membrane.WebRTC.Metrics.metrics/0","type":"function"},{"doc":"Module representing a WebRTC track.","ref":"Membrane.WebRTC.Track.html","title":"Membrane.WebRTC.Track","type":"module"},{"doc":"Creates `t:t/0` from SDP m-line with random track id and stream id.","ref":"Membrane.WebRTC.Track.html#from_sdp_media/1","title":"Membrane.WebRTC.Track.from_sdp_media/1","type":"function"},{"doc":"Creates `t:t/0` from SDP m-line with specific track id and stream id.","ref":"Membrane.WebRTC.Track.html#from_sdp_media/3","title":"Membrane.WebRTC.Track.from_sdp_media/3","type":"function"},{"doc":"Creates a new track.\n\nTracks belonging to the same stream should have the same `stream_id`,\nthat can be generated with `stream_id/0`.","ref":"Membrane.WebRTC.Track.html#new/3","title":"Membrane.WebRTC.Track.new/3","type":"function"},{"doc":"Modifies track properties according to provided constraints.\n\nIn particular, after setting constraints, track can be disabled.","ref":"Membrane.WebRTC.Track.html#set_constraints/3","title":"Membrane.WebRTC.Track.set_constraints/3","type":"function"},{"doc":"Determines if the track is using simulcast","ref":"Membrane.WebRTC.Track.html#simulcast?/1","title":"Membrane.WebRTC.Track.simulcast?/1","type":"function"},{"doc":"Generates stream id, that can be used to mark tracks belonging to the same stream.","ref":"Membrane.WebRTC.Track.html#stream_id/0","title":"Membrane.WebRTC.Track.stream_id/0","type":"function"},{"doc":"","ref":"Membrane.WebRTC.Track.html#to_otel_data/1","title":"Membrane.WebRTC.Track.to_otel_data/1","type":"function"},{"doc":"","ref":"Membrane.WebRTC.Track.html#t:encoding_key/0","title":"Membrane.WebRTC.Track.encoding_key/0","type":"type"},{"doc":"","ref":"Membrane.WebRTC.Track.html#t:id/0","title":"Membrane.WebRTC.Track.id/0","type":"type"},{"doc":"","ref":"Membrane.WebRTC.Track.html#t:rid/0","title":"Membrane.WebRTC.Track.rid/0","type":"type"},{"doc":"","ref":"Membrane.WebRTC.Track.html#t:status/0","title":"Membrane.WebRTC.Track.status/0","type":"type"},{"doc":"","ref":"Membrane.WebRTC.Track.html#t:t/0","title":"Membrane.WebRTC.Track.t/0","type":"type"},{"doc":"A struct holding data passed via SDP about a possible encoding of a track","ref":"Membrane.WebRTC.Track.Encoding.html","title":"Membrane.WebRTC.Track.Encoding","type":"module"},{"doc":"","ref":"Membrane.WebRTC.Track.Encoding.html#t:t/0","title":"Membrane.WebRTC.Track.Encoding.t/0","type":"type"},{"doc":"# Membrane WebRTC plugin\n\n[![Hex.pm](https://img.shields.io/hexpm/v/membrane_webrtc_plugin.svg)](https://hex.pm/packages/membrane_webrtc_plugin)\n[![API Docs](https://img.shields.io/badge/api-docs-yellow.svg?style=flat)](https://hexdocs.pm/membrane_webrtc_plugin)\n[![CircleCI](https://circleci.com/gh/jellyfish-dev/membrane_webrtc_plugin.svg?style=svg)](https://circleci.com/gh/jellyfish-dev/membrane_webrtc_plugin)\n\nPlugin for sending and receiving media with WebRTC.\n\nIt is part of [Membrane Multimedia Framework](https://membraneframework.org).","ref":"readme.html","title":"Membrane WebRTC plugin","type":"extras"},{"doc":"The package can be installed by adding `membrane_webrtc_plugin` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:membrane_webrtc_plugin, \"~> 0.16.0\"}\n  ]\nend\n```","ref":"readme.html#installation","title":"Installation - Membrane WebRTC plugin","type":"extras"},{"doc":"TODO","ref":"readme.html#usage","title":"Usage - Membrane WebRTC plugin","type":"extras"},{"doc":"Copyright 2020, [Software Mansion](https://swmansion.com/?utm_source=git&utm_medium=readme&utm_campaign=membrane_webrtc_plugin)\n\n[![Software Mansion](https://logo.swmansion.com/logo?color=white&variant=desktop&width=200&tag=membrane-github)](https://swmansion.com/?utm_source=git&utm_medium=readme&utm_campaign=membrane_webrtc_plugin)\n\nLicensed under the [Apache License, Version 2.0](LICENSE)","ref":"readme.html#copyright-and-license","title":"Copyright and License - Membrane WebRTC plugin","type":"extras"},{"doc":"Apache License\n                           Version 2.0, January 2004\n                        http://www.apache.org/licenses/\n\n   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION\n\n   1. Definitions.\n\n      \"License\" shall mean the terms and conditions for use, reproduction,\n      and distribution as defined by Sections 1 through 9 of this document.\n\n      \"Licensor\" shall mean the copyright owner or entity authorized by\n      the copyright owner that is granting the License.\n\n      \"Legal Entity\" shall mean the union of the acting entity and all\n      other entities that control, are controlled by, or are under common\n      control with that entity. For the purposes of this definition,\n      \"control\" means (i) the power, direct or indirect, to cause the\n      direction or management of such entity, whether by contract or\n      otherwise, or (ii) ownership of fifty percent (50%) or more of the\n      outstanding shares, or (iii) beneficial ownership of such entity.\n\n      \"You\" (or \"Your\") shall mean an individual or Legal Entity\n      exercising permissions granted by this License.\n\n      \"Source\" form shall mean the preferred form for making modifications,\n      including but not limited to software source code, documentation\n      source, and configuration files.\n\n      \"Object\" form shall mean any form resulting from mechanical\n      transformation or translation of a Source form, including but\n      not limited to compiled object code, generated documentation,\n      and conversions to other media types.\n\n      \"Work\" shall mean the work of authorship, whether in Source or\n      Object form, made available under the License, as indicated by a\n      copyright notice that is included in or attached to the work\n      (an example is provided in the Appendix below).\n\n      \"Derivative Works\" shall mean any work, whether in Source or Object\n      form, that is based on (or derived from) the Work and for which the\n      editorial revisions, annotations, elaborations, or other modifications\n      represent, as a whole, an original work of authorship. For the purposes\n      of this License, Derivative Works shall not include works that remain\n      separable from, or merely link (or bind by name) to the interfaces of,\n      the Work and Derivative Works thereof.\n\n      \"Contribution\" shall mean any work of authorship, including\n      the original version of the Work and any modifications or additions\n      to that Work or Derivative Works thereof, that is intentionally\n      submitted to Licensor for inclusion in the Work by the copyright owner\n      or by an individual or Legal Entity authorized to submit on behalf of\n      the copyright owner. For the purposes of this definition, \"submitted\"\n      means any form of electronic, verbal, or written communication sent\n      to the Licensor or its representatives, including but not limited to\n      communication on electronic mailing lists, source code control systems,\n      and issue tracking systems that are managed by, or on behalf of, the\n      Licensor for the purpose of discussing and improving the Work, but\n      excluding communication that is conspicuously marked or otherwise\n      designated in writing by the copyright owner as \"Not a Contribution.\"\n\n      \"Contributor\" shall mean Licensor and any individual or Legal Entity\n      on behalf of whom a Contribution has been received by Licensor and\n      subsequently incorporated within the Work.\n\n   2. Grant of Copyright License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      copyright license to reproduce, prepare Derivative Works of,\n      publicly display, publicly perform, sublicense, and distribute the\n      Work and such Derivative Works in Source or Object form.\n\n   3. Grant of Patent License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      (except as stated in this section) patent license to make, have made,\n      use, offer to sell, sell, import, and otherwise transfer the Work,\n      where such license applies only to those patent claims licensable\n      by such Contributor that are necessarily infringed by their\n      Contribution(s) alone or by combination of their Contribution(s)\n      with the Work to which such Contribution(s) was submitted. If You\n      institute patent litigation against any entity (including a\n      cross-claim or counterclaim in a lawsuit) alleging that the Work\n      or a Contribution incorporated within the Work constitutes direct\n      or contributory patent infringement, then any patent licenses\n      granted to You under this License for that Work shall terminate\n      as of the date such litigation is filed.\n\n   4. Redistribution. You may reproduce and distribute copies of the\n      Work or Derivative Works thereof in any medium, with or without\n      modifications, and in Source or Object form, provided that You\n      meet the following conditions:\n\n      (a) You must give any other recipients of the Work or\n          Derivative Works a copy of this License; and\n\n      (b) You must cause any modified files to carry prominent notices\n          stating that You changed the files; and\n\n      (c) You must retain, in the Source form of any Derivative Works\n          that You distribute, all copyright, patent, trademark, and\n          attribution notices from the Source form of the Work,\n          excluding those notices that do not pertain to any part of\n          the Derivative Works; and\n\n      (d) If the Work includes a \"NOTICE\" text file as part of its\n          distribution, then any Derivative Works that You distribute must\n          include a readable copy of the attribution notices contained\n          within such NOTICE file, excluding those notices that do not\n          pertain to any part of the Derivative Works, in at least one\n          of the following places: within a NOTICE text file distributed\n          as part of the Derivative Works; within the Source form or\n          documentation, if provided along with the Derivative Works; or,\n          within a display generated by the Derivative Works, if and\n          wherever such third-party notices normally appear. The contents\n          of the NOTICE file are for informational purposes only and\n          do not modify the License. You may add Your own attribution\n          notices within Derivative Works that You distribute, alongside\n          or as an addendum to the NOTICE text from the Work, provided\n          that such additional attribution notices cannot be construed\n          as modifying the License.\n\n      You may add Your own copyright statement to Your modifications and\n      may provide additional or different license terms and conditions\n      for use, reproduction, or distribution of Your modifications, or\n      for any such Derivative Works as a whole, provided Your use,\n      reproduction, and distribution of the Work otherwise complies with\n      the conditions stated in this License.\n\n   5. Submission of Contributions. Unless You explicitly state otherwise,\n      any Contribution intentionally submitted for inclusion in the Work\n      by You to the Licensor shall be under the terms and conditions of\n      this License, without any additional terms or conditions.\n      Notwithstanding the above, nothing herein shall supersede or modify\n      the terms of any separate license agreement you may have executed\n      with Licensor regarding such Contributions.\n\n   6. Trademarks. This License does not grant permission to use the trade\n      names, trademarks, service marks, or product names of the Licensor,\n      except as required for reasonable and customary use in describing the\n      origin of the Work and reproducing the content of the NOTICE file.\n\n   7. Disclaimer of Warranty. Unless required by applicable law or\n      agreed to in writing, Licensor provides the Work (and each\n      Contributor provides its Contributions) on an \"AS IS\" BASIS,\n      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or\n      implied, including, without limitation, any warranties or conditions\n      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A\n      PARTICULAR PURPOSE. You are solely responsible for determining the\n      appropriateness of using or redistributing the Work and assume any\n      risks associated with Your exercise of permissions under this License.\n\n   8. Limitation of Liability. In no event and under no legal theory,\n      whether in tort (including negligence), contract, or otherwise,\n      unless required by applicable law (such as deliberate and grossly\n      negligent acts) or agreed to in writing, shall any Contributor be\n      liable to You for damages, including any direct, indirect, special,\n      incidental, or consequential damages of any character arising as a\n      result of this License or out of the use or inability to use the\n      Work (including but not limited to damages for loss of goodwill,\n      work stoppage, computer failure or malfunction, or any and all\n      other commercial damages or losses), even if such Contributor\n      has been advised of the possibility of such damages.\n\n   9. Accepting Warranty or Additional Liability. While redistributing\n      the Work or Derivative Works thereof, You may choose to offer,\n      and charge a fee for, acceptance of support, warranty, indemnity,\n      or other liability obligations and/or rights consistent with this\n      License. However, in accepting such obligations, You may act only\n      on Your own behalf and on Your sole responsibility, not on behalf\n      of any other Contributor, and only if You agree to indemnify,\n      defend, and hold each Contributor harmless for any liability\n      incurred by, or claims asserted against, such Contributor by reason\n      of your accepting any such warranty or additional liability.\n\n   END OF TERMS AND CONDITIONS\n\n   APPENDIX: How to apply the Apache License to your work.\n\n      To apply the Apache License to your work, attach the following\n      boilerplate notice, with the fields enclosed by brackets \"[]\"\n      replaced with your own identifying information. (Don't include\n      the brackets!)  The text should be enclosed in the appropriate\n      comment syntax for the file format. We also recommend that a\n      file or class name and description of purpose be included on the\n      same \"printed page\" as the copyright notice for easier\n      identification within third-party archives.\n\n   Copyright 2020 Software Mansion\n\n   Licensed under the Apache License, Version 2.0 (the \"License\");\n   you may not use this file except in compliance with the License.\n   You may obtain a copy of the License at\n\n       http://www.apache.org/licenses/LICENSE-2.0\n\n   Unless required by applicable law or agreed to in writing, software\n   distributed under the License is distributed on an \"AS IS\" BASIS,\n   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\n   See the License for the specific language governing permissions and\n   limitations under the License.","ref":"license.html","title":"LICENSE","type":"extras"}]}